package com.example.nto.domain.exception.advice;

import com.amazonaws.services.organizations.model.ConstraintViolationException;
import com.example.nto.domain.exception.*;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;

@ControllerAdvice
public class GlobalExceptionalHandler {
    // При выбрасывании исключений EmployeeNotFoundException и CodeNotFoundException возвращает клиенту код 401.
    // При выбрасывании исключения SomethingWentWrongException возвращает 400.

    @ExceptionHandler(EmployeeNotFoundException.class)
    public ResponseEntity<HttpStatus> handlerEmployeeNotFoundException(EmployeeNotFoundException e) {
        return new ResponseEntity<>(HttpStatus.UNAUTHORIZED);
    }

    @ExceptionHandler(CodeNotFoundException.class)
    public ResponseEntity<HttpStatus> handlerCodeNotFoundException(CodeNotFoundException e) {
        return new ResponseEntity<>(HttpStatus.UNAUTHORIZED);
    }

    @ExceptionHandler(SomethingWentWrongException.class)
    public ResponseEntity<HttpStatus> handlerSomethingWentWrongException(SomethingWentWrongException e) {
        return new ResponseEntity<>(HttpStatus.BAD_REQUEST);
    }

    @ExceptionHandler(AccessDeniedException.class)
    public ResponseEntity<String> handlerAccessDeniedException(AccessDeniedException e) {
        return new ResponseEntity<>(e.getMessage(), HttpStatus.UNAUTHORIZED);
    }

    @ExceptionHandler(ResourceNotFoundException.class)
    public ResponseEntity<String> handlerAccessDeniedException(ResourceNotFoundException e) {
        return new ResponseEntity<>(e.getMessage(), HttpStatus.NOT_FOUND);
    }

    @ExceptionHandler(ConflictResourceException.class)
    public ResponseEntity<String> handlerConflictResourceException(ConflictResourceException e) {
        return new ResponseEntity<>(e.getMessage(), HttpStatus.CONFLICT);
    }

    @ExceptionHandler(ImageUploadException.class)
    public ResponseEntity<String> handlerImageUploadException(ImageUploadException e) {
        return new ResponseEntity<>(e.getMessage(), HttpStatus.INTERNAL_SERVER_ERROR);
    }

    @ExceptionHandler(ImageSendException.class)
    public ResponseEntity<String> handlerImageSendException(ImageSendException e) {
        return new ResponseEntity<>(e.getMessage(), HttpStatus.INTERNAL_SERVER_ERROR);
    }

    @ExceptionHandler(ConstraintViolationException.class)
    public ResponseEntity<String> handlerConstraintViolationException(ConstraintViolationException e) {
        return new ResponseEntity<>(e.getMessage(), HttpStatus.BAD_REQUEST);
    }
}


